pub struct CommitteeVotesInner {
pub tx_hash: String,
pub voter_hot_id: String,
pub proposal_id: String,
pub proposal_tx_hash: String,
pub proposal_index: i32,
pub governance_type: GovernanceType,
pub vote: Vote,
pub metadata_url: Option<String>,
pub metadata_hash: Option<String>,
pub block_height: i32,
pub block_time: i32,
}Fields
tx_hash: StringHash of the vote transaction.
voter_hot_id: StringCIP-129 bech32 encoded hot credential of the committee member that cast this vote (cc_hot1...).
proposal_id: StringCIP-129 Governance Action Identifier of the proposal being voted on.
proposal_tx_hash: StringHash of the proposal transaction.
proposal_index: i32Index of the proposal within its transaction.
governance_type: GovernanceTypeType of the governance action being voted on.
vote: VoteThe Vote. Can be one of yes, no, abstain.
metadata_url: Option<String>Voting anchor URL — pointer to the off-chain rationale published by the voter.
metadata_hash: Option<String>Hex hash of the off-chain anchor document.
block_height: i32Block height of the vote transaction.
block_time: i32Block creation time in UNIX time of the vote transaction.
Implementations