pub struct DrepMetadataError {
pub code: Code,
pub message: String,
}Expand description
DrepMetadataError : Present when metadata could not be fetched or validated.
Fields
code: CodeStable machine-readable error code.
message: StringHuman-readable description of the error.
Implementations
Sourceimpl DrepMetadataError
impl DrepMetadataError
Sourcepub fn new(code: Code, message: String) -> DrepMetadataError
pub fn new(code: Code, message: String) -> DrepMetadataError
Present when metadata could not be fetched or validated.