pub struct DrepsInnerMetadata {
pub url: String,
pub hash: String,
pub json_metadata: Option<Value>,
pub bytes: Option<String>,
pub error: Option<Box<DrepsInnerMetadataError>>,
}Expand description
DrepsInnerMetadata : Off-chain metadata associated with the DRep’s latest registration. null when the DRep has no registration anchor (e.g. special DReps such as drep_always_abstain / drep_always_no_confidence). When an anchor exists but the off-chain content could not be fetched or validated, error is populated and json_metadata / bytes are null.
Fields
url: StringURL to the drep metadata
hash: StringHash of the metadata file
json_metadata: Option<Value>Content of the JSON metadata (validated CIP-119)
bytes: Option<String>Content of the metadata (raw)
error: Option<Box<DrepsInnerMetadataError>>Implementations
Sourceimpl DrepsInnerMetadata
impl DrepsInnerMetadata
Sourcepub fn new(
url: String,
hash: String,
json_metadata: Option<Value>,
bytes: Option<String>,
) -> DrepsInnerMetadata
pub fn new( url: String, hash: String, json_metadata: Option<Value>, bytes: Option<String>, ) -> DrepsInnerMetadata
Off-chain metadata associated with the DRep’s latest registration. null when the DRep has no registration anchor (e.g. special DReps such as drep_always_abstain / drep_always_no_confidence). When an anchor exists but the off-chain content could not be fetched or validated, error is populated and json_metadata / bytes are null.